@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- *      email: rkeene@netfueldesign.com
+ *      email: rkeene@rkeene.org
  */
 
 
@@ -34,6 +34,13 @@
 	out_block	- Where to put data after compression.
 	blk_size	- Size of prev_block and curr_block.
 */
+
+#if defined(AS_MODULE) && defined(USE_MODULES)
+int DC_NUM=1;
+void *DC_ALGO=comp_rle_algo;
+char *DC_NAME="RLE Compression (MOD)";
+#endif
+
 int comp_rle_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	switch(mode) {
 		case DACT_MODE_COMPR:
